# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from .._utils import PropertyInfo

__all__ = ["VaultConfirmUploadParams", "Variant0", "Variant1"]


class Variant0(TypedDict, total=False):
    id: Required[str]

    size_bytes: Required[Annotated[int, PropertyInfo(alias="sizeBytes")]]
    """Uploaded file size in bytes (required when success=true)"""

    success: Required[Literal[True]]

    error_code: Annotated[str, PropertyInfo(alias="errorCode")]
    """Client-side error code (required when success=false)"""

    error_message: Annotated[str, PropertyInfo(alias="errorMessage")]
    """Client-side error message (required when success=false)"""

    etag: str
    """S3 ETag for the uploaded object (optional if client cannot access ETag header)"""


class Variant1(TypedDict, total=False):
    id: Required[str]

    error_code: Required[Annotated[str, PropertyInfo(alias="errorCode")]]
    """Client-side error code (required when success=false)"""

    error_message: Required[Annotated[str, PropertyInfo(alias="errorMessage")]]
    """Client-side error message (required when success=false)"""

    success: Required[Literal[False]]

    etag: str
    """S3 ETag for the uploaded object (optional if client cannot access ETag header)"""

    size_bytes: Annotated[int, PropertyInfo(alias="sizeBytes")]
    """Uploaded file size in bytes (required when success=true)"""


VaultConfirmUploadParams: TypeAlias = Union[Variant0, Variant1]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev.types.vault import MultipartGetPartURLsResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMultipart:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_abort(self, client: Casedev) -> None:
        multipart = client.vault.multipart.abort(
            id="id",
            object_id="objectId",
            upload_id="uploadId",
        )
        assert multipart is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_abort(self, client: Casedev) -> None:
        response = client.vault.multipart.with_raw_response.abort(
            id="id",
            object_id="objectId",
            upload_id="uploadId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        multipart = response.parse()
        assert multipart is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_abort(self, client: Casedev) -> None:
        with client.vault.multipart.with_streaming_response.abort(
            id="id",
            object_id="objectId",
            upload_id="uploadId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            multipart = response.parse()
            assert multipart is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_abort(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.multipart.with_raw_response.abort(
                id="",
                object_id="objectId",
                upload_id="uploadId",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_part_urls(self, client: Casedev) -> None:
        multipart = client.vault.multipart.get_part_urls(
            id="id",
            object_id="objectId",
            parts=[
                {
                    "part_number": 1,
                    "size_bytes": 1,
                }
            ],
            upload_id="uploadId",
        )
        assert_matches_type(MultipartGetPartURLsResponse, multipart, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_part_urls(self, client: Casedev) -> None:
        response = client.vault.multipart.with_raw_response.get_part_urls(
            id="id",
            object_id="objectId",
            parts=[
                {
                    "part_number": 1,
                    "size_bytes": 1,
                }
            ],
            upload_id="uploadId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        multipart = response.parse()
        assert_matches_type(MultipartGetPartURLsResponse, multipart, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_part_urls(self, client: Casedev) -> None:
        with client.vault.multipart.with_streaming_response.get_part_urls(
            id="id",
            object_id="objectId",
            parts=[
                {
                    "part_number": 1,
                    "size_bytes": 1,
                }
            ],
            upload_id="uploadId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            multipart = response.parse()
            assert_matches_type(MultipartGetPartURLsResponse, multipart, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_part_urls(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.vault.multipart.with_raw_response.get_part_urls(
                id="",
                object_id="objectId",
                parts=[
                    {
                        "part_number": 1,
                        "size_bytes": 1,
                    }
                ],
                upload_id="uploadId",
            )


class TestAsyncMultipart:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_abort(self, async_client: AsyncCasedev) -> None:
        multipart = await async_client.vault.multipart.abort(
            id="id",
            object_id="objectId",
            upload_id="uploadId",
        )
        assert multipart is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_abort(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.multipart.with_raw_response.abort(
            id="id",
            object_id="objectId",
            upload_id="uploadId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        multipart = await response.parse()
        assert multipart is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_abort(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.multipart.with_streaming_response.abort(
            id="id",
            object_id="objectId",
            upload_id="uploadId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            multipart = await response.parse()
            assert multipart is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_abort(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.multipart.with_raw_response.abort(
                id="",
                object_id="objectId",
                upload_id="uploadId",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_part_urls(self, async_client: AsyncCasedev) -> None:
        multipart = await async_client.vault.multipart.get_part_urls(
            id="id",
            object_id="objectId",
            parts=[
                {
                    "part_number": 1,
                    "size_bytes": 1,
                }
            ],
            upload_id="uploadId",
        )
        assert_matches_type(MultipartGetPartURLsResponse, multipart, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_part_urls(self, async_client: AsyncCasedev) -> None:
        response = await async_client.vault.multipart.with_raw_response.get_part_urls(
            id="id",
            object_id="objectId",
            parts=[
                {
                    "part_number": 1,
                    "size_bytes": 1,
                }
            ],
            upload_id="uploadId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        multipart = await response.parse()
        assert_matches_type(MultipartGetPartURLsResponse, multipart, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_part_urls(self, async_client: AsyncCasedev) -> None:
        async with async_client.vault.multipart.with_streaming_response.get_part_urls(
            id="id",
            object_id="objectId",
            parts=[
                {
                    "part_number": 1,
                    "size_bytes": 1,
                }
            ],
            upload_id="uploadId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            multipart = await response.parse()
            assert_matches_type(MultipartGetPartURLsResponse, multipart, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_part_urls(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.vault.multipart.with_raw_response.get_part_urls(
                id="",
                object_id="objectId",
                parts=[
                    {
                        "part_number": 1,
                        "size_bytes": 1,
                    }
                ],
                upload_id="uploadId",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .search import (
    SearchResource,
    AsyncSearchResource,
    SearchResourceWithRawResponse,
    AsyncSearchResourceWithRawResponse,
    SearchResourceWithStreamingResponse,
    AsyncSearchResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "SearchResource",
    "AsyncSearchResource",
    "SearchResourceWithRawResponse",
    "AsyncSearchResourceWithRawResponse",
    "SearchResourceWithStreamingResponse",
    "AsyncSearchResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .superdoc import (
    SuperdocResource,
    AsyncSuperdocResource,
    SuperdocResourceWithRawResponse,
    AsyncSuperdocResourceWithRawResponse,
    SuperdocResourceWithStreamingResponse,
    AsyncSuperdocResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "SuperdocResource",
    "AsyncSuperdocResource",
    "SuperdocResourceWithRawResponse",
    "AsyncSuperdocResourceWithRawResponse",
    "SuperdocResourceWithStreamingResponse",
    "AsyncSuperdocResourceWithStreamingResponse",
]
